/* Jatha -- bringing to Java some of the power of lisp.
 * Copyright (C) 2001  Kimberley Burchett   kimbly@pobox.com
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package jatha;

/**
 * This macro factory tries to create macros by dynamically loading a class 
 * in the "macros" package with the same name as the macro call.  For example, 
 * if a file contains the macro call @FOO(a,b), this factory will try to load 
 * the class macros.FOO, create a new instance, and cast it to a Macro.
 * 
 * @see jatha.MacroFactory
 */
public class DefaultMacroFactory implements MacroFactory {
	public Macro createMacro(String macroName, Expander expander) {
		try {
			Class c = Class.forName("macros."+macroName);
			return (Macro)c.newInstance();
		}
		catch (ClassNotFoundException e) { return null; }
		catch (InstantiationException e) { return null; }
		catch (IllegalAccessException e) { return null; }
		catch (ClassCastException e)     { return null; }
		catch (ClassFormatError e) {
			expander.trace("ClassFormatError when loading \""+macroName+
				"\" macro: "+e.getMessage()+".  You may have used "+
				"the wrong capitalization.");
			return null;
		}
	}
}
