/* Jatha -- bringing to Java some of the power of lisp.
 * Copyright (C) 2001  Kimberley Burchett   kimbly@pobox.com
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package jatha;

/**
 * MacroFactories are used to create Macro objects when a macro call is 
 * encountered in a file.  For example, if a file contains @foo(x,y),
 * the Expander would go through the registered MacroFactories and 
 * ask each in turn to try to create a macro called "foo".  The default 
 * macro factory uses Class.forName() to create the macro.  Other factories 
 * could use other techniques; for example, a C-style #define could be 
 * simulated by using a factory which allows new macros to be defined on 
 * the fly.
 * 
 * <p>Note: you must register your factory with the Expander class.
 * 
 * <p>Note: if two factories handle the same macro name, it is undefined
 * which one will win.
 * 
 * @see jatha.DefaultMacroFactory
 * @see jatha.Expander
 */
public interface MacroFactory {
	/** Returns null if this factory can't create the requested macro */
	public Macro createMacro(String macroName, Expander expander);
}
